@@ -198,7 +198,7 @@ void Canvas::slotCanvasSize(double r, double g)
 
 void Canvas::slotPrint(const QString& text)
 {
-	QGraphicsTextItem *ti = new QGraphicsTextItem(text, 0);
+    QGraphicsTextItem *ti = new QGraphicsTextItem(text, nullptr);
 	_scene->addItem(ti);
 // 	ti->setDefaultTextColor(textColor);
 	ti->setFont(*textFont);
@@ -210,11 +210,11 @@ void Canvas::slotPrint(const QString& text)
 void Canvas::slotFontType(const QString& family, const QString& extra)
 {
 	textFont->setFamily(family);
-	textFont->setBold(extra.contains(i18n("bold")) > 0);
-	textFont->setItalic(extra.contains(i18n("italic")) > 0);
-	textFont->setUnderline(extra.contains(i18n("underline")) > 0);
-	textFont->setOverline(extra.contains(i18n("overline")) > 0);
-	textFont->setStrikeOut(extra.contains(i18n("strikeout")) > 0);
+	textFont->setBold(extra.contains(i18n("bold")));
+	textFont->setItalic(extra.contains(i18n("italic")));
+	textFont->setUnderline(extra.contains(i18n("underline")));
+	textFont->setOverline(extra.contains(i18n("overline")));
+	textFont->setStrikeOut(extra.contains(i18n("strikeout")));
 }
 
 void Canvas::slotReset()
